"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var LambdaReply = /** @class */ (function () {
    /**
     * Creates a reply template with the selected defaults.
     *
     * @param defaults - The defaults to apply for each response made using this template.
     */
    function LambdaReply(defaults) {
        if (defaults === void 0) { defaults = {}; }
        this.defaults = {
            headers: __assign({ 'Content-Type': 'application/json' }, (defaults.headers || {})),
            multiValueHeaders: (defaults.multiValueHeaders || {}),
            isBase64Encoded: defaults.isBase64Encoded || false,
        };
    }
    /**
     * Create a AWS Lambda response object.
     *
     * @param statusCode - HTTP status code
     * @param body - The response body to return.
     * @param options - Customize the response. Overwrite headers or set the response as base64 encoded.
     */
    LambdaReply.prototype.make = function (statusCode, body, options) {
        if (body === void 0) { body = ''; }
        if (options === void 0) { options = {}; }
        return {
            statusCode: statusCode,
            body: body,
            headers: __assign({}, this.defaults.headers, (options.headers || {})),
            multiValueHeaders: __assign({}, this.defaults.multiValueHeaders, (options.multiValueHeaders || {})),
            isBase64Encoded: options.isBase64Encoded !== undefined ? options.isBase64Encoded : this.defaults.isBase64Encoded,
        };
    };
    return LambdaReply;
}());
exports.LambdaReply = LambdaReply;
